@@ -271,7 +271,7 @@ typedef struct st_partition_part_key_multi_range_hld
   /* Owner object */
   ha_partition *partition;
 
-  /* id of the the partition this structure is for */
+  /* id of the partition this structure is for */
   uint32 part_id;
 
   /* Current range we're iterating through */
@@ -468,11 +468,11 @@ public:
   {
     return m_is_clone_of;
   }
-  virtual part_id_range *get_part_spec()
+  part_id_range *get_part_spec()
   {
     return &m_part_spec;
   }
-  virtual uint get_no_current_part_id()
+  uint get_no_current_part_id()
   {
     return NO_CURRENT_PART_ID;
   }
@@ -493,18 +493,10 @@ public:
 
   bool vers_can_native(THD *thd) override
   {
-    if (thd->lex->part_info)
-    {
-      // PARTITION BY SYSTEM_TIME is not supported for now
-      return thd->lex->part_info->part_type != VERSIONING_PARTITION;
-    }
-    else
-    {
-      bool can= true;
-      for (uint i= 0; i < m_tot_parts && can; i++)
-        can= can && m_file[i]->vers_can_native(thd);
-      return can;
-    }
+    bool can= true;
+    for (uint i= 0; i < m_tot_parts && can; i++)
+      can= can && m_file[i]->vers_can_native(thd);
+    return can;
   }
 
   /*
@@ -552,7 +544,8 @@ public:
              HA_CREATE_INFO *create_info) override;
   int create_partitioning_metadata(const char *name,
                                    const char *old_name,
-                                   chf_create_flags action_flag)
+                                   chf_create_flags action_flag,
+                                   bool ignore_delete_error)
     override;
   bool check_if_updates_are_ignored(const char *op) const override;
   void update_create_info(HA_CREATE_INFO *create_info) override;
@@ -869,7 +862,8 @@ public:
                        const key_range * end_key,
                        bool eq_range, bool sorted) override;
   int read_range_next() override;
-
+  void set_end_range(const key_range *end_key,
+                     enum_range_scan_direction direction) override;
 
   HANDLER_BUFFER *m_mrr_buffer;
   uint *m_mrr_buffer_size;
@@ -926,7 +920,7 @@ public:
   /* Range iterator structure to be supplied to partitions */
   RANGE_SEQ_IF m_part_seq_if;
 
-  virtual int multi_range_key_create_key(
+  int multi_range_key_create_key(
     RANGE_SEQ_IF *seq,
     range_seq_t seq_it
   );
@@ -1326,10 +1320,6 @@ public:
       The underlying storage engine might support Rowid Filtering. But
       ha_partition does not forward the needed SE API calls, so the feature
       will not be used.
-
-      Note: It's the same with IndexConditionPushdown, except for its variant
-      of IndexConditionPushdown+BatchedKeyAccess (that one works). Because of
-      that, we do not clear HA_DO_INDEX_COND_PUSHDOWN here.
     */
     return part_flags & ~HA_DO_RANGE_FILTER_PUSHDOWN;
   }
@@ -1394,7 +1384,7 @@ public:
 private:
   int reset_auto_increment(ulonglong value) override;
   int update_next_auto_inc_val();
-  virtual void lock_auto_increment()
+  void lock_auto_increment()
   {
     /* lock already taken */
     if (auto_increment_safe_stmt_log_lock)
@@ -1406,7 +1396,7 @@ private:
       auto_increment_lock= TRUE;
     }
   }
-  virtual void unlock_auto_increment()
+  void unlock_auto_increment()
   {
     /*
       If auto_increment_safe_stmt_log_lock is true, we have to keep the lock.
@@ -1419,7 +1409,7 @@ private:
       part_share->unlock_auto_inc();
     }
   }
-  virtual void set_auto_increment_if_higher(Field *field)
+  void set_auto_increment_if_higher(Field *field)
   {
     ulonglong nr= (((Field_num*) field)->unsigned_flag ||
                    field->val_int() > 0) ? field->val_int() : 0;
@@ -1567,6 +1557,8 @@ public:
     const COND *cond_push(const COND *cond) override;
     void cond_pop() override;
     int info_push(uint info_type, void *info) override;
+    Item *idx_cond_push(uint keyno, Item* idx_cond) override;
+    void cancel_pushed_idx_cond() override;
 
     private:
     int handle_opt_partitions(THD *thd, HA_CHECK_OPT *check_opt, uint flags);
